[svn:parrot] r38621 - in branches/gc_api: docs docs/dev docs/pdds include/parrot src src/dynpmc src/gc src/io src/pmc

whiteknight at svn.parrot.org whiteknight at svn.parrot.org
Sat May 9 00:17:39 UTC 2009


Author: whiteknight
Date: Sat May  9 00:17:36 2009
New Revision: 38621
URL: https://trac.parrot.org/parrot/changeset/38621

Log:
[gc_api] rename pobject_lives Parrot_gc_mark_PObj_alive

Modified:
   branches/gc_api/docs/dev/pmc_freeze.pod
   branches/gc_api/docs/pdds/pdd09_gc.pod
   branches/gc_api/docs/pmc.pod
   branches/gc_api/include/parrot/gc_api.h
   branches/gc_api/src/dynpmc/dynlexpad.pmc
   branches/gc_api/src/dynpmc/pair.pmc
   branches/gc_api/src/gc/api.c
   branches/gc_api/src/gc/gc_private.h
   branches/gc_api/src/gc/generational_ms.c
   branches/gc_api/src/gc/incremental_ms.c
   branches/gc_api/src/gc/mark_sweep.c
   branches/gc_api/src/gc/system.c
   branches/gc_api/src/hash.c
   branches/gc_api/src/io/core.c
   branches/gc_api/src/key.c
   branches/gc_api/src/list.c
   branches/gc_api/src/oo.c
   branches/gc_api/src/packfile.c
   branches/gc_api/src/pmc/callsignature.pmc
   branches/gc_api/src/pmc/capture.pmc
   branches/gc_api/src/pmc/class.pmc
   branches/gc_api/src/pmc/cpointer.pmc
   branches/gc_api/src/pmc/eval.pmc
   branches/gc_api/src/pmc/eventhandler.pmc
   branches/gc_api/src/pmc/exception.pmc
   branches/gc_api/src/pmc/exceptionhandler.pmc
   branches/gc_api/src/pmc/exporter.pmc
   branches/gc_api/src/pmc/filehandle.pmc
   branches/gc_api/src/pmc/fixedpmcarray.pmc
   branches/gc_api/src/pmc/fixedstringarray.pmc
   branches/gc_api/src/pmc/iterator.pmc
   branches/gc_api/src/pmc/namespace.pmc
   branches/gc_api/src/pmc/nci.pmc
   branches/gc_api/src/pmc/object.pmc
   branches/gc_api/src/pmc/orderedhash.pmc
   branches/gc_api/src/pmc/packfile.pmc
   branches/gc_api/src/pmc/packfileannotationkeys.pmc
   branches/gc_api/src/pmc/packfileannotations.pmc
   branches/gc_api/src/pmc/packfileconstanttable.pmc
   branches/gc_api/src/pmc/packfiledirectory.pmc
   branches/gc_api/src/pmc/packfilefixupentry.pmc
   branches/gc_api/src/pmc/packfilefixuptable.pmc
   branches/gc_api/src/pmc/packfilerawsegment.pmc
   branches/gc_api/src/pmc/packfilesegment.pmc
   branches/gc_api/src/pmc/pmcproxy.pmc
   branches/gc_api/src/pmc/role.pmc
   branches/gc_api/src/pmc/scheduler.pmc
   branches/gc_api/src/pmc/schedulermessage.pmc
   branches/gc_api/src/pmc/socket.pmc
   branches/gc_api/src/pmc/string.pmc
   branches/gc_api/src/pmc/stringhandle.pmc
   branches/gc_api/src/pmc/sub.pmc
   branches/gc_api/src/pmc/task.pmc
   branches/gc_api/src/pmc/unmanagedstruct.pmc
   branches/gc_api/src/stacks.c
   branches/gc_api/src/sub.c
   branches/gc_api/src/vtables.c

Modified: branches/gc_api/docs/dev/pmc_freeze.pod
==============================================================================
--- branches/gc_api/docs/dev/pmc_freeze.pod	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/docs/dev/pmc_freeze.pod	Sat May  9 00:17:36 2009	(r38621)
@@ -58,7 +58,7 @@
 
 =item mark
 
-Mark all objects as being live by calling B<pobject_lives> called from GC.
+Mark all objects as being live by calling B<Parrot_gc_mark_PObj_alive> called from GC.
 While the functionality is the same, it will not be implemented on top of this
 general scheme for performance reasons. This leads to some code duplication,
 but GC is run permanently and deserves all the speed it can get.

Modified: branches/gc_api/docs/pdds/pdd09_gc.pod
==============================================================================
--- branches/gc_api/docs/pdds/pdd09_gc.pod	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/docs/pdds/pdd09_gc.pod	Sat May  9 00:17:36 2009	(r38621)
@@ -570,7 +570,7 @@
 =item PObj_custom_mark_FLAG
 
 The C<mark> vtable slot will be called during the GC mark phase. The mark
-function must call C<pobject_lives> for all non-NULL objects (Buffers and
+function must call C<Parrot_gc_mark_PObj_alive> for all non-NULL objects (Buffers and
 PMCs) that PMC refers to. This flag is typically tested and the custom mark
 VTABLE method called from C<src/gc/api.c:mark_special>.
 

Modified: branches/gc_api/docs/pmc.pod
==============================================================================
--- branches/gc_api/docs/pmc.pod	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/docs/pmc.pod	Sat May  9 00:17:36 2009	(r38621)
@@ -87,7 +87,7 @@
 =head1 PMCs and GC
 
 The GC system doesn't make any assumptions about your PMC's layout. Whenever a
-PMC is found in the root set, B<pobject_lives()> is called with that PMC.  The
+PMC is found in the root set, B<Parrot_gc_mark_PObj_alive()> is called with that PMC.  The
 PMC is responsible to mark all contained or referenced active Parrot objects
 (Buffers, STRINGs or other PMCs) when its C<mark()> VTABLE function is called.
 
@@ -107,7 +107,7 @@
 
 If your PMC contains any other B<PObj>s (STRINGs, PMCs, etc), your PMC must
 implement the B<mark()> VTABLE function and set this flag.  The B<mark()>
-VTABLE function must call B<pobject_lives()> on all B<PObj>s which your PMC
+VTABLE function must call B<Parrot_gc_mark_PObj_alive()> on all B<PObj>s which your PMC
 contains.
 
 =item PObj_active_destroy_FLAG

Modified: branches/gc_api/include/parrot/gc_api.h
==============================================================================
--- branches/gc_api/include/parrot/gc_api.h	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/include/parrot/gc_api.h	Sat May  9 00:17:36 2009	(r38621)
@@ -200,7 +200,7 @@
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 
 PARROT_EXPORT
-void pobject_lives(PARROT_INTERP, ARGMOD(PObj *obj))
+void Parrot_gc_mark_PObj_alive(PARROT_INTERP, ARGMOD(PObj *obj))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*obj);
@@ -309,7 +309,7 @@
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*str);
 
-#define ASSERT_ARGS_pobject_lives __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_Parrot_gc_mark_PObj_alive __attribute__unused__ int _ASSERT_ARGS_CHECK = \
        PARROT_ASSERT_ARG(interp) \
     || PARROT_ASSERT_ARG(obj)
 #define ASSERT_ARGS_Parrot_allocate_aligned __attribute__unused__ int _ASSERT_ARGS_CHECK = \
@@ -381,7 +381,7 @@
         __attribute__nonnull__(1);
 
 PARROT_EXPORT
-void parrot_gc_gms_pobject_lives(PARROT_INTERP, ARGMOD(PObj *obj))
+void parrot_gc_gms_Parrot_gc_mark_PObj_alive(PARROT_INTERP, ARGMOD(PObj *obj))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*obj);
@@ -410,7 +410,7 @@
 
 #define ASSERT_ARGS_Parrot_gc_gms_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
        PARROT_ASSERT_ARG(interp)
-#define ASSERT_ARGS_parrot_gc_gms_pobject_lives __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_parrot_gc_gms_Parrot_gc_mark_PObj_alive __attribute__unused__ int _ASSERT_ARGS_CHECK = \
        PARROT_ASSERT_ARG(interp) \
     || PARROT_ASSERT_ARG(obj)
 #define ASSERT_ARGS_parrot_gc_gms_wb __attribute__unused__ int _ASSERT_ARGS_CHECK = \

Modified: branches/gc_api/src/dynpmc/dynlexpad.pmc
==============================================================================
--- branches/gc_api/src/dynpmc/dynlexpad.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/dynpmc/dynlexpad.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -203,7 +203,7 @@
     VTABLE void mark() {
         PMC *std_pad = PARROT_DYNLEXPAD(SELF)->init;
         if (std_pad)
-            pobject_lives(interp, (PObj *)std_pad);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)std_pad);
         if (PARROT_DYNLEXPAD(SELF)->hash)
             parrot_mark_hash(interp, PARROT_DYNLEXPAD(SELF)->hash);
     }

Modified: branches/gc_api/src/dynpmc/pair.pmc
==============================================================================
--- branches/gc_api/src/dynpmc/pair.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/dynpmc/pair.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -87,10 +87,10 @@
         Parrot_Pair_attributes * const pair = PARROT_PAIR(SELF);
 
         if (pair->key)
-            pobject_lives(INTERP, (PObj *)pair->key);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)pair->key);
 
         if (pair->value)
-            pobject_lives(INTERP, (PObj *)pair->value);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)pair->value);
     }
 
 /*

Modified: branches/gc_api/src/gc/api.c
==============================================================================
--- branches/gc_api/src/gc/api.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/gc/api.c	Sat May  9 00:17:36 2009	(r38621)
@@ -88,7 +88,7 @@
 
 /*
 
-=item C<void pobject_lives(PARROT_INTERP, PObj *obj)>
+=item C<void Parrot_gc_mark_PObj_alive(PARROT_INTERP, PObj *obj)>
 
 Marks the PObj as "alive" for the Garbage Collector. Takes a pointer to a PObj,
 and performs necessary marking to ensure the PMC and its direct children nodes
@@ -101,14 +101,14 @@
 
 PARROT_EXPORT
 void
-pobject_lives(PARROT_INTERP, ARGMOD(PObj *obj))
+Parrot_gc_mark_PObj_alive(PARROT_INTERP, ARGMOD(PObj *obj))
 {
-    ASSERT_ARGS(pobject_lives)
+    ASSERT_ARGS(Parrot_gc_mark_PObj_alive)
 #if PARROT_GC_GMS
     do {
         if (!PObj_live_TEST(obj) && \
                 PObj_to_GMSH(obj)->gen->gen_no >= interp->gc_generation) \
-            parrot_gc_gms_pobject_lives(interp, obj); \
+            parrot_gc_gms_Parrot_gc_mark_PObj_alive(interp, obj); \
     } while (0);
 #else /* not PARROT_GC_GMS */
 

Modified: branches/gc_api/src/gc/gc_private.h
==============================================================================
--- branches/gc_api/src/gc/gc_private.h	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/gc/gc_private.h	Sat May  9 00:17:36 2009	(r38621)
@@ -67,7 +67,7 @@
         __attribute__nonnull__(1);
 
 PARROT_EXPORT
-void parrot_gc_gms_pobject_lives(PARROT_INTERP, ARGMOD(PObj *obj))
+void parrot_gc_gms_Parrot_gc_mark_PObj_alive(PARROT_INTERP, ARGMOD(PObj *obj))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*obj);
@@ -96,7 +96,7 @@
 
 #define ASSERT_ARGS_Parrot_gc_gms_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
        PARROT_ASSERT_ARG(interp)
-#define ASSERT_ARGS_parrot_gc_gms_pobject_lives __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_parrot_gc_gms_Parrot_gc_mark_PObj_alive __attribute__unused__ int _ASSERT_ARGS_CHECK = \
        PARROT_ASSERT_ARG(interp) \
     || PARROT_ASSERT_ARG(obj)
 #define ASSERT_ARGS_parrot_gc_gms_wb __attribute__unused__ int _ASSERT_ARGS_CHECK = \

Modified: branches/gc_api/src/gc/generational_ms.c
==============================================================================
--- branches/gc_api/src/gc/generational_ms.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/gc/generational_ms.c	Sat May  9 00:17:36 2009	(r38621)
@@ -1452,9 +1452,9 @@
 
 /*
 
-=item C<void parrot_gc_gms_pobject_lives(PARROT_INTERP, PObj *obj)>
+=item C<void parrot_gc_gms_Parrot_gc_mark_PObj_alive(PARROT_INTERP, PObj *obj)>
 
-Set the object live - called by the pobject_lives macro
+Set the object live - called by the Parrot_gc_mark_PObj_alive macro
 
 =cut
 
@@ -1462,9 +1462,9 @@
 
 PARROT_EXPORT
 void
-parrot_gc_gms_pobject_lives(PARROT_INTERP, ARGMOD(PObj *obj))
+parrot_gc_gms_Parrot_gc_mark_PObj_alive(PARROT_INTERP, ARGMOD(PObj *obj))
 {
-    ASSERT_ARGS(parrot_gc_gms_pobject_lives)
+    ASSERT_ARGS(parrot_gc_gms_Parrot_gc_mark_PObj_alive)
     Gc_gms_hdr *h;
     int priority;
 
@@ -1545,7 +1545,7 @@
         const Gc_gms_hdr **p;
         for (p = s->store; p < s->ptr; ++p) {
             Gc_gms_hdr * const h = *p;
-            pobject_lives(interp, GMSH_to_PObj(h));
+            Parrot_gc_mark_PObj_alive(interp, GMSH_to_PObj(h));
         }
     }
     return 0;
@@ -1598,7 +1598,7 @@
                 arena_base->num_early_gc_PMCs) {
             return 1;
         }
-        /* TODO propagate flag in pobject_lives */
+        /* TODO propagate flag in Parrot_gc_mark_PObj_alive */
         arena_base->gc_trace_ptr = current;
         if (!PObj_needs_early_gc_TEST(current))
             PObj_high_priority_gc_CLEAR(current);

Modified: branches/gc_api/src/gc/incremental_ms.c
==============================================================================
--- branches/gc_api/src/gc/incremental_ms.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/gc/incremental_ms.c	Sat May  9 00:17:36 2009	(r38621)
@@ -1133,10 +1133,10 @@
     IMS_DEBUG((stderr, "%d agg %p mark %p\n",
                 ((Gc_ims_private *)interp->arena_base->
                 gc_private)->state, agg, _new));
-    pobject_lives(interp, (PObj*)_new);
+    Parrot_gc_mark_PObj_alive(interp, (PObj*)_new);
 #else
     PObj_get_FLAGS(agg) &= ~ (PObj_live_FLAG|PObj_custom_GC_FLAG);
-    pobject_lives(interp, (PObj*)agg);
+    Parrot_gc_mark_PObj_alive(interp, (PObj*)agg);
 #endif
 }
 

Modified: branches/gc_api/src/gc/mark_sweep.c
==============================================================================
--- branches/gc_api/src/gc/mark_sweep.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/gc/mark_sweep.c	Sat May  9 00:17:36 2009	(r38621)
@@ -178,7 +178,7 @@
         /* keep the scheduler and its kids alive for Task-like PMCs to destroy
          * themselves; run a sweep to collect them */
         if (interp->scheduler) {
-            pobject_lives(interp, (PObj *)interp->scheduler);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)interp->scheduler);
             VTABLE_mark(interp, interp->scheduler);
             Parrot_gc_sweep(interp, interp->arena_base->pmc_pool);
         }
@@ -295,12 +295,12 @@
     }
 
     /* mark it as used  */
-    pobject_lives(interp, (PObj *)interp->iglobals);
+    Parrot_gc_mark_PObj_alive(interp, (PObj *)interp->iglobals);
 
     /* mark the current continuation */
     obj = (PObj *)interp->current_cont;
     if (obj && obj != (PObj *)NEED_CONTINUATION)
-        pobject_lives(interp, obj);
+        Parrot_gc_mark_PObj_alive(interp, obj);
 
     /* mark the current context. */
     ctx = CONTEXT(interp);
@@ -321,11 +321,11 @@
     mark_vtables(interp);
 
     /* mark the root_namespace */
-    pobject_lives(interp, (PObj *)interp->root_namespace);
+    Parrot_gc_mark_PObj_alive(interp, (PObj *)interp->root_namespace);
 
     /* mark the concurrency scheduler */
     if (interp->scheduler)
-        pobject_lives(interp, (PObj *)interp->scheduler);
+        Parrot_gc_mark_PObj_alive(interp, (PObj *)interp->scheduler);
 
     /* s. packfile.c */
     mark_const_subs(interp);
@@ -334,11 +334,11 @@
     mark_object_cache(interp);
 
     /* Now mark the class hash */
-    pobject_lives(interp, (PObj *)interp->class_hash);
+    Parrot_gc_mark_PObj_alive(interp, (PObj *)interp->class_hash);
 
     /* Mark the registry */
     PARROT_ASSERT(interp->gc_registry);
-    pobject_lives(interp, (PObj *)interp->gc_registry);
+    Parrot_gc_mark_PObj_alive(interp, (PObj *)interp->gc_registry);
 
     /* Mark the MMD cache. */
     if (interp->op_mmd_cache)
@@ -995,7 +995,7 @@
 
         /* mark properties */
         if (PMC_metadata(current))
-            pobject_lives(interp, (PObj *)PMC_metadata(current));
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)PMC_metadata(current));
 
          if (PObj_custom_mark_TEST(current)) {
             PARROT_ASSERT(!PObj_on_free_list_TEST(current));

Modified: branches/gc_api/src/gc/system.c
==============================================================================
--- branches/gc_api/src/hash.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/hash.c	Sat May  9 00:17:36 2009	(r38621)
@@ -439,7 +439,7 @@
                     hash, (int)entries);
 
             PARROT_ASSERT(bucket->key);
-            pobject_lives(interp, (PObj *)bucket->key);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)bucket->key);
 
             bucket = bucket->next;
         }
@@ -475,7 +475,7 @@
                         hash, (int)entries);
 
             PARROT_ASSERT(bucket->value);
-            pobject_lives(interp, (PObj *)bucket->value);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)bucket->value);
 
             bucket = bucket->next;
         }
@@ -511,10 +511,10 @@
                         hash, (int)entries);
 
             PARROT_ASSERT(bucket->key);
-            pobject_lives(interp, (PObj *)bucket->key);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)bucket->key);
 
             PARROT_ASSERT(bucket->value);
-            pobject_lives(interp, (PObj *)bucket->value);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)bucket->value);
 
             bucket = bucket->next;
         }

Modified: branches/gc_api/src/io/core.c
==============================================================================
--- branches/gc_api/src/io/core.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/io/core.c	Sat May  9 00:17:36 2009	(r38621)
@@ -126,7 +126,7 @@
      */
     for (i = 0; i < 3; i++) {
         if (table[i]) {
-            pobject_lives(interp, (PObj *)table[i]);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)table[i]);
         }
     }
 }

Modified: branches/gc_api/src/key.c
==============================================================================
--- branches/gc_api/src/key.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/key.c	Sat May  9 00:17:36 2009	(r38621)
@@ -615,7 +615,7 @@
 
     if (flags == KEY_string_FLAG) {
         GETATTR_Key_str_key(interp, key, str_key);
-        pobject_lives(interp, (PObj *)str_key);
+        Parrot_gc_mark_PObj_alive(interp, (PObj *)str_key);
     }
 
     /*
@@ -629,7 +629,7 @@
     /* if iteration hasn't started, above flag isn't set yet */
     GETATTR_Key_next_key(interp, key, next_key);
     if (next_key && (void *)next_key != (void *)INITBucketIndex)
-        pobject_lives(interp, (PObj *)next_key);
+        Parrot_gc_mark_PObj_alive(interp, (PObj *)next_key);
 
 }
 

Modified: branches/gc_api/src/list.c
==============================================================================
--- branches/gc_api/src/list.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/list.c	Sat May  9 00:17:36 2009	(r38621)
@@ -1540,7 +1540,7 @@
     List_chunk *chunk;
 
     for (chunk = list->first; chunk; chunk = chunk->next) {
-        pobject_lives(interp, (PObj *)chunk);
+        Parrot_gc_mark_PObj_alive(interp, (PObj *)chunk);
         if (list->item_type == enum_type_PMC ||
                 list->item_type == enum_type_STRING) {
             if (!(chunk->flags & sparse)) {
@@ -1549,14 +1549,14 @@
 
                 for (i = 0; i < chunk->items; i++, ++p) {
                     if (*p)
-                        pobject_lives(interp, *p);
+                        Parrot_gc_mark_PObj_alive(interp, *p);
                 }
             }
 
         }
     }
 
-    pobject_lives(interp, (PObj *)list);
+    Parrot_gc_mark_PObj_alive(interp, (PObj *)list);
 }
 
 /*

Modified: branches/gc_api/src/oo.c
==============================================================================
--- branches/gc_api/src/oo.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/oo.c	Sat May  9 00:17:36 2009	(r38621)
@@ -623,7 +623,7 @@
         for (entry = 0; entry < TBL_SIZE; ++entry) {
             Meth_cache_entry *e = mc->idx[type][entry];
             while (e) {
-                pobject_lives(interp, (PObj *)e->pmc);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)e->pmc);
                 e = e->next;
             }
         }

Modified: branches/gc_api/src/packfile.c
==============================================================================
--- branches/gc_api/src/packfile.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/packfile.c	Sat May  9 00:17:36 2009	(r38621)
@@ -802,7 +802,7 @@
         if (constants[i]->type == PFC_PMC) {
             PMC * const pmc = constants[i]->u.key;
             if (pmc)
-                pobject_lives(interp, (PObj *)pmc);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)pmc);
         }
     }
 }

Modified: branches/gc_api/src/pmc/callsignature.pmc
==============================================================================
--- branches/gc_api/src/pmc/callsignature.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/callsignature.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -191,15 +191,15 @@
         if (attrs) {
 
             if (attrs->array)
-                pobject_lives(interp, (PObj*)attrs->array);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)attrs->array);
             if (attrs->hash)
-                pobject_lives(interp, (PObj*)attrs->hash);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)attrs->hash);
             if (attrs->returns)
-                pobject_lives(interp, (PObj*)attrs->returns);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)attrs->returns);
             if (attrs->type_tuple)
-                pobject_lives(interp, (PObj*)attrs->type_tuple);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)attrs->type_tuple);
             if (attrs->short_sig)
-                pobject_lives(interp, (PObj*)attrs->short_sig);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)attrs->short_sig);
         }
 
         if (!data)
@@ -207,7 +207,7 @@
 
         for (i = attrs->data_size - 1; i >= 0; --i)
             if (data[i])
-                pobject_lives(interp, (PObj *)data[i]);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)data[i]);
     }
 
 

Modified: branches/gc_api/src/pmc/capture.pmc
==============================================================================
--- branches/gc_api/src/pmc/capture.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/capture.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -525,7 +525,7 @@
 
         for (i = PARROT_CAPTURE(SELF)->data_size - 1; i >= 0; --i)
             if (data[i])
-                pobject_lives(interp, (PObj *)data[i]);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)data[i]);
     }
 
 /*

Modified: branches/gc_api/src/pmc/class.pmc
==============================================================================
--- branches/gc_api/src/pmc/class.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/class.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -596,31 +596,31 @@
     VTABLE void mark() {
         Parrot_Class_attributes * const _class = PARROT_CLASS(SELF);
         if (_class->name)
-            pobject_lives(interp, (PObj *)_class->name);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->name);
         if (_class->fullname)
-            pobject_lives(interp, (PObj *)_class->fullname);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->fullname);
         if (_class->_namespace)
-            pobject_lives(interp, (PObj *)_class->_namespace);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->_namespace);
         if (_class->parents)
-            pobject_lives(interp, (PObj *)_class->parents);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->parents);
         if (_class->all_parents)
-            pobject_lives(interp, (PObj *)_class->all_parents);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->all_parents);
         if (_class->roles)
-            pobject_lives(interp, (PObj *)_class->roles);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->roles);
         if (_class->methods)
-            pobject_lives(interp, (PObj *)_class->methods);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->methods);
         if (_class->vtable_overrides)
-            pobject_lives(interp, (PObj *)_class->vtable_overrides);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->vtable_overrides);
         if (_class->parent_overrides)
-            pobject_lives(interp, (PObj *)_class->parent_overrides);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->parent_overrides);
         if (_class->attrib_metadata)
-            pobject_lives(interp, (PObj *)_class->attrib_metadata);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->attrib_metadata);
         if (_class->attrib_index)
-            pobject_lives(interp, (PObj *)_class->attrib_index);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->attrib_index);
         if (_class->attrib_cache)
-            pobject_lives(interp, (PObj *)_class->attrib_cache);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->attrib_cache);
         if (_class->resolve_method)
-            pobject_lives(interp, (PObj *)_class->resolve_method);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_class->resolve_method);
     }
 
 

Modified: branches/gc_api/src/pmc/cpointer.pmc
==============================================================================
--- branches/gc_api/src/pmc/cpointer.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/cpointer.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -88,18 +88,18 @@
         Parrot_CPointer_attributes * const data = PARROT_CPOINTER(SELF);
 
         if (data->sig)
-            pobject_lives(interp, (PObj *)data->sig);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data->sig);
 
         if (data->pointer) {
             if (Parrot_str_equal(interp, data->sig, CONST_STRING(interp, "P"))) {
                 PMC ** const pmc_pointer = (PMC **) data->pointer;
                 PARROT_ASSERT(*pmc_pointer);
-                pobject_lives(interp, (PObj *) *pmc_pointer);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *) *pmc_pointer);
             }
             else if (Parrot_str_equal(interp, data->sig, CONST_STRING(interp, "S"))) {
                 STRING ** const str_pointer = (STRING **) data->pointer;
                 PARROT_ASSERT(*str_pointer);
-                pobject_lives(interp, (PObj *) *str_pointer);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *) *str_pointer);
             }
         }
     }

Modified: branches/gc_api/src/pmc/eval.pmc
==============================================================================
--- branches/gc_api/src/pmc/eval.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/eval.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -121,7 +121,7 @@
             PMC      *sub = ct->constants[ci]->u.key;
 
             if (!PMC_IS_NULL(sub))
-                pobject_lives(interp, (PObj *)sub);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)sub);
         }
     }
 }

Modified: branches/gc_api/src/pmc/eventhandler.pmc
==============================================================================
--- branches/gc_api/src/pmc/eventhandler.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/eventhandler.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -133,13 +133,13 @@
 
         if (e) {
             if (e->type)
-                pobject_lives(INTERP, (PObj *)e->type);
+                Parrot_gc_mark_PObj_alive(INTERP, (PObj *)e->type);
 
             if (! PMC_IS_NULL(e->interp))
-                pobject_lives(INTERP, (PObj *)e->interp);
+                Parrot_gc_mark_PObj_alive(INTERP, (PObj *)e->interp);
 
             if (! PMC_IS_NULL(e->code))
-                pobject_lives(INTERP, (PObj *)e->code);
+                Parrot_gc_mark_PObj_alive(INTERP, (PObj *)e->code);
         }
     }
 

Modified: branches/gc_api/src/pmc/exception.pmc
==============================================================================
--- branches/gc_api/src/pmc/exception.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/exception.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -152,15 +152,15 @@
     VTABLE void mark() {
         Parrot_Exception_attributes * const core_struct = PARROT_EXCEPTION(SELF);
         if (core_struct->message)
-            pobject_lives(interp, (PObj *)core_struct->message);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->message);
         if (core_struct->payload)
-            pobject_lives(interp, (PObj *)core_struct->payload);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->payload);
         if (core_struct->resume)
-            pobject_lives(interp, (PObj *)core_struct->resume);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->resume);
         if (core_struct->backtrace)
-            pobject_lives(interp, (PObj *)core_struct->backtrace);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->backtrace);
         if (core_struct->handler_iter)
-            pobject_lives(interp, (PObj *)core_struct->handler_iter);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->handler_iter);
     }
 
 /*

Modified: branches/gc_api/src/pmc/exceptionhandler.pmc
==============================================================================
--- branches/gc_api/src/pmc/exceptionhandler.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/exceptionhandler.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -74,9 +74,9 @@
         Parrot_ExceptionHandler_attributes * const core_struct =
             PARROT_EXCEPTIONHANDLER(SELF);
         if (core_struct->handled_types)
-            pobject_lives(interp, (PObj *)core_struct->handled_types);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->handled_types);
         if (core_struct->handled_types_except)
-            pobject_lives(interp, (PObj *)core_struct->handled_types_except);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->handled_types_except);
     }
 
     VTABLE PMC *clone() {

Modified: branches/gc_api/src/pmc/exporter.pmc
==============================================================================
--- branches/gc_api/src/pmc/exporter.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/exporter.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -153,11 +153,11 @@
         Parrot_Exporter_attributes *exp = PARROT_EXPORTER(SELF);
 
         if (exp->ns_src)
-            pobject_lives(interp, (PObj *)exp->ns_src);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)exp->ns_src);
         if (exp->ns_dest)
-            pobject_lives(interp, (PObj *)exp->ns_dest);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)exp->ns_dest);
         if (exp->globals)
-            pobject_lives(interp, (PObj *)exp->globals);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)exp->globals);
     }
 
 

Modified: branches/gc_api/src/pmc/filehandle.pmc
==============================================================================
--- branches/gc_api/src/pmc/filehandle.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/filehandle.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -124,11 +124,11 @@
     VTABLE void mark() {
         Parrot_FileHandle_attributes * const data_struct = PARROT_FILEHANDLE(SELF);
         if (data_struct->mode)
-            pobject_lives(interp, (PObj *)data_struct->mode);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data_struct->mode);
         if (data_struct->filename)
-            pobject_lives(interp, (PObj *)data_struct->filename);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data_struct->filename);
         if (data_struct->encoding)
-            pobject_lives(interp, (PObj *)data_struct->encoding);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data_struct->encoding);
     }
 
 /*

Modified: branches/gc_api/src/pmc/fixedpmcarray.pmc
==============================================================================
--- branches/gc_api/src/pmc/fixedpmcarray.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/fixedpmcarray.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -800,7 +800,7 @@
 
         for (i = PMC_size(SELF) - 1; i >= 0; --i)
             if (data[i])
-                pobject_lives(interp, (PObj *)data[i]);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)data[i]);
     }
 
 

Modified: branches/gc_api/src/pmc/fixedstringarray.pmc
==============================================================================
--- branches/gc_api/src/pmc/fixedstringarray.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/fixedstringarray.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -129,7 +129,7 @@
 
             for (i = 0; i < size; i++) {
                 if (str_array[i])
-                    pobject_lives(INTERP, (PObj *) str_array[i]);
+                    Parrot_gc_mark_PObj_alive(INTERP, (PObj *) str_array[i]);
             }
         }
     }

Modified: branches/gc_api/src/pmc/iterator.pmc
==============================================================================
--- branches/gc_api/src/pmc/iterator.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/iterator.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -145,11 +145,11 @@
         PMC *key;
         GET_ATTR_key(INTERP, SELF, key);
         if (key)
-             pobject_lives(INTERP, (PObj *)key);
+             Parrot_gc_mark_PObj_alive(INTERP, (PObj *)key);
 
         /* the aggregate */
         if (SELF.get_pmc() != PMCNULL)
-             pobject_lives(INTERP, (PObj *)SELF.get_pmc());
+             Parrot_gc_mark_PObj_alive(INTERP, (PObj *)SELF.get_pmc());
     }
 
 /*

Modified: branches/gc_api/src/pmc/namespace.pmc
==============================================================================
--- branches/gc_api/src/pmc/namespace.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/namespace.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -167,15 +167,15 @@
         Parrot_NameSpace_attributes * const nsinfo = PARROT_NAMESPACE(SELF);
         SUPER();
         if (nsinfo->parent)
-            pobject_lives(INTERP, (PObj *)nsinfo->parent);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)nsinfo->parent);
         if (nsinfo->name)
-            pobject_lives(INTERP, (PObj *)nsinfo->name);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)nsinfo->name);
         if (nsinfo->_class)
-            pobject_lives(INTERP, (PObj *)nsinfo->_class);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)nsinfo->_class);
         if (nsinfo->vtable)
-            pobject_lives(INTERP, (PObj *)nsinfo->vtable);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)nsinfo->vtable);
         if (nsinfo->methods)
-            pobject_lives(INTERP, (PObj *)nsinfo->methods);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)nsinfo->methods);
     }
 
 /*

Modified: branches/gc_api/src/pmc/nci.pmc
==============================================================================
--- branches/gc_api/src/pmc/nci.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/nci.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -210,9 +210,9 @@
             Parrot_NCI_attributes * const nci_info = PARROT_NCI(SELF);
 
             if (nci_info->signature)
-                pobject_lives(interp, (PObj*)nci_info->signature);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)nci_info->signature);
             if (nci_info->pcc_params_signature)
-                pobject_lives(interp, (PObj*)nci_info->pcc_params_signature);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)nci_info->pcc_params_signature);
         }
     }
 

Modified: branches/gc_api/src/pmc/object.pmc
==============================================================================
--- branches/gc_api/src/pmc/object.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/object.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -189,9 +189,9 @@
             Parrot_Object_attributes * const obj = PARROT_OBJECT(SELF);
 
             if (obj->_class)
-                pobject_lives(interp, (PObj*)obj->_class);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)obj->_class);
             if (obj->attrib_store)
-                pobject_lives(interp, (PObj*)obj->attrib_store);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)obj->attrib_store);
         }
     }
 

Modified: branches/gc_api/src/pmc/orderedhash.pmc
==============================================================================
--- branches/gc_api/src/pmc/orderedhash.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/orderedhash.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -67,9 +67,9 @@
             while (b) {
 
                 if (b->key) {
-                    pobject_lives(interp, (PObj *)b->key);
+                    Parrot_gc_mark_PObj_alive(interp, (PObj *)b->key);
                     if (b->value)
-                        pobject_lives(interp, (PObj *)b->value);
+                        Parrot_gc_mark_PObj_alive(interp, (PObj *)b->value);
                 }
 
                 b = b->next;

Modified: branches/gc_api/src/pmc/packfile.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfile.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfile.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -115,9 +115,9 @@
         Parrot_Packfile_attributes * attrs = PARROT_PACKFILE(SELF);
 
         if (attrs->uuid)
-            pobject_lives(INTERP, (PObj *)attrs->uuid);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)attrs->uuid);
         if (attrs->directory)
-            pobject_lives(INTERP, (PObj *)attrs->directory);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)attrs->directory);
     }
 /*
 

Modified: branches/gc_api/src/pmc/packfileannotationkeys.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfileannotationkeys.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfileannotationkeys.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -86,11 +86,11 @@
                 PARROT_PACKFILEANNOTATIONKEYS(SELF);
 
         if (attrs->const_table)
-            pobject_lives(interp, (PObj *)attrs->const_table);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->const_table);
         if (attrs->names)
-            pobject_lives(interp, (PObj *)attrs->names);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->names);
         if (attrs->types)
-            pobject_lives(interp, (PObj *)attrs->types);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->types);
     }
 
 /*

Modified: branches/gc_api/src/pmc/packfileannotations.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfileannotations.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfileannotations.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -72,9 +72,9 @@
                 PARROT_PACKFILEANNOTATIONS(SELF);
 
         if (attrs->annotations)
-            pobject_lives(interp, (PObj *)attrs->annotations);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->annotations);
         if (attrs->keys)
-            pobject_lives(interp, (PObj *)attrs->keys);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->keys);
     }
 
 /*

Modified: branches/gc_api/src/pmc/packfileconstanttable.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfileconstanttable.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfileconstanttable.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -69,9 +69,9 @@
                 PARROT_PACKFILECONSTANTTABLE(SELF);
 
         if (attrs->constants)
-            pobject_lives(interp, (PObj *)attrs->constants);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->constants);
         if (attrs->types)
-            pobject_lives(interp, (PObj *)attrs->types);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->types);
     }
 
 /*

Modified: branches/gc_api/src/pmc/packfiledirectory.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfiledirectory.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfiledirectory.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -65,7 +65,7 @@
                 PARROT_PACKFILEDIRECTORY(SELF);
 
         if (attrs->hash)
-            pobject_lives(interp, (PObj *)attrs->hash);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->hash);
     }
 
 /*

Modified: branches/gc_api/src/pmc/packfilefixupentry.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfilefixupentry.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfilefixupentry.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -61,7 +61,7 @@
                 PARROT_PACKFILEFIXUPENTRY(SELF);
 
         if (attrs->name)
-            pobject_lives(interp, (PObj *)attrs->name);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->name);
     }
 
 /*

Modified: branches/gc_api/src/pmc/packfilefixuptable.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfilefixuptable.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfilefixuptable.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -65,7 +65,7 @@
                 PARROT_PACKFILEFIXUPTABLE(SELF);
 
         if (attrs->entries)
-            pobject_lives(interp, (PObj *)attrs->entries);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->entries);
     }
 
 /*

Modified: branches/gc_api/src/pmc/packfilerawsegment.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfilerawsegment.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfilerawsegment.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -65,7 +65,7 @@
                 PARROT_PACKFILERAWSEGMENT(SELF);
 
         if (attrs->opcodes)
-            pobject_lives(interp, (PObj *)attrs->opcodes);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->opcodes);
     }
 
 /*

Modified: branches/gc_api/src/pmc/packfilesegment.pmc
==============================================================================
--- branches/gc_api/src/pmc/packfilesegment.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/packfilesegment.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -67,7 +67,7 @@
                 PARROT_PACKFILESEGMENT(SELF);
 
         if (attrs->directory)
-            pobject_lives(interp, (PObj *)attrs->directory);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)attrs->directory);
     }
 
 /*

Modified: branches/gc_api/src/pmc/pmcproxy.pmc
==============================================================================
--- branches/gc_api/src/pmc/pmcproxy.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/pmcproxy.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -229,29 +229,29 @@
         Parrot_Class_attributes * const _pmc = PARROT_CLASS(SELF);
 
         if (_pmc->name)
-            pobject_lives(interp, (PObj *)_pmc->name);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->name);
         if (_pmc->_namespace)
-            pobject_lives(interp, (PObj *)_pmc->_namespace);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->_namespace);
         if (_pmc->parents)
-            pobject_lives(interp, (PObj *)_pmc->parents);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->parents);
         if (_pmc->all_parents)
-            pobject_lives(interp, (PObj *)_pmc->all_parents);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->all_parents);
         if (_pmc->roles)
-            pobject_lives(interp, (PObj *)_pmc->roles);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->roles);
         if (_pmc->methods)
-            pobject_lives(interp, (PObj *)_pmc->methods);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->methods);
         if (_pmc->vtable_overrides)
-            pobject_lives(interp, (PObj *)_pmc->vtable_overrides);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->vtable_overrides);
         if (_pmc->parent_overrides)
-            pobject_lives(interp, (PObj *)_pmc->parent_overrides);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->parent_overrides);
         if (_pmc->attrib_metadata)
-            pobject_lives(interp, (PObj *)_pmc->attrib_metadata);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->attrib_metadata);
         if (_pmc->attrib_index)
-            pobject_lives(interp, (PObj *)_pmc->attrib_index);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->attrib_index);
         if (_pmc->attrib_cache)
-            pobject_lives(interp, (PObj *)_pmc->attrib_cache);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->attrib_cache);
         if (_pmc->resolve_method)
-            pobject_lives(interp, (PObj *)_pmc->resolve_method);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)_pmc->resolve_method);
     }
 
 /*

Modified: branches/gc_api/src/pmc/role.pmc
==============================================================================
--- branches/gc_api/src/pmc/role.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/role.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -273,15 +273,15 @@
         Parrot_Role_attributes * const role = PARROT_ROLE(SELF);
 
         if (role->name)
-            pobject_lives(interp, (PObj *)role->name);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)role->name);
         if (role->_namespace)
-            pobject_lives(interp, (PObj *)role->_namespace);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)role->_namespace);
         if (role->roles)
-            pobject_lives(interp, (PObj *)role->roles);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)role->roles);
         if (role->methods)
-            pobject_lives(interp, (PObj *)role->methods);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)role->methods);
         if (role->attrib_metadata)
-            pobject_lives(interp, (PObj *)role->attrib_metadata);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)role->attrib_metadata);
     }
 
 /*

Modified: branches/gc_api/src/pmc/scheduler.pmc
==============================================================================
--- branches/gc_api/src/pmc/scheduler.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/scheduler.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -267,15 +267,15 @@
             Parrot_Scheduler_attributes * const core_struct = PARROT_SCHEDULER(SELF);
 
             if (core_struct->task_list)
-                pobject_lives(interp, (PObj *)core_struct->task_list);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->task_list);
             if (core_struct->task_index)
-                pobject_lives(interp, (PObj *)core_struct->task_index);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->task_index);
             if (core_struct->wait_index)
-                pobject_lives(interp, (PObj *)core_struct->wait_index);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->wait_index);
             if (core_struct->handlers)
-                pobject_lives(interp, (PObj *)core_struct->handlers);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->handlers);
             if (core_struct->messages)
-                pobject_lives(interp, (PObj *)core_struct->messages);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)core_struct->messages);
         }
     }
 

Modified: branches/gc_api/src/pmc/schedulermessage.pmc
==============================================================================
--- branches/gc_api/src/pmc/schedulermessage.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/schedulermessage.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -216,7 +216,7 @@
                 PARROT_SCHEDULERMESSAGE(SELF);
 
             if (core_struct->data)
-                pobject_lives(interp, (PObj*)core_struct->data);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)core_struct->data);
         }
     }
 

Modified: branches/gc_api/src/pmc/socket.pmc
==============================================================================
--- branches/gc_api/src/pmc/socket.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/socket.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -82,10 +82,10 @@
 
         if (data) {
             if (data->local)
-                pobject_lives(interp, (PObj *)data->local);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)data->local);
 
             if (data->remote)
-                pobject_lives(interp, (PObj *)data->remote);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)data->remote);
         }
     }
 /*

Modified: branches/gc_api/src/pmc/string.pmc
==============================================================================
--- branches/gc_api/src/pmc/string.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/string.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -98,7 +98,7 @@
         GET_ATTR_str_val(INTERP, SELF, str_val);
 
         if (str_val)
-            pobject_lives(INTERP, (PObj *)str_val);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)str_val);
     }
 
 /*

Modified: branches/gc_api/src/pmc/stringhandle.pmc
==============================================================================
--- branches/gc_api/src/pmc/stringhandle.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/stringhandle.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -95,13 +95,13 @@
     VTABLE void mark() {
         Parrot_StringHandle_attributes * const data_struct = PARROT_STRINGHANDLE(SELF);
         if (data_struct->stringhandle)
-            pobject_lives(interp, (PObj *)data_struct->stringhandle);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data_struct->stringhandle);
         if (data_struct->mode)
-            pobject_lives(interp, (PObj *)data_struct->mode);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data_struct->mode);
         if (data_struct->encoding)
-            pobject_lives(interp, (PObj *)data_struct->encoding);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data_struct->encoding);
         if (data_struct->filename)
-            pobject_lives(interp, (PObj *)data_struct->filename);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)data_struct->filename);
     }
 
 /*

Modified: branches/gc_api/src/pmc/sub.pmc
==============================================================================
--- branches/gc_api/src/pmc/sub.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/sub.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -470,23 +470,23 @@
             return;
 
         if (sub->name)
-            pobject_lives(INTERP, (PObj *) sub->name);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->name);
         if (sub->method_name)
-            pobject_lives(INTERP, (PObj *) sub->method_name);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->method_name);
         if (sub->ns_entry_name)
-            pobject_lives(INTERP, (PObj *) sub->ns_entry_name);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->ns_entry_name);
         if (!PMC_IS_NULL(sub->namespace_name))
-            pobject_lives(INTERP, (PObj *) sub->namespace_name);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->namespace_name);
         if (!PMC_IS_NULL(sub->multi_signature))
-            pobject_lives(INTERP, (PObj *) sub->multi_signature);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->multi_signature);
         if (!PMC_IS_NULL(sub->lex_info))
-            pobject_lives(INTERP, (PObj *) sub->lex_info);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->lex_info);
         if (!PMC_IS_NULL(sub->outer_sub))
-            pobject_lives(INTERP, (PObj *) sub->outer_sub);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->outer_sub);
         if (!PMC_IS_NULL(sub->eval_pmc))
-            pobject_lives(INTERP, (PObj *) sub->eval_pmc);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->eval_pmc);
         if (sub->subid)
-            pobject_lives(INTERP, (PObj *) sub->subid);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *) sub->subid);
         if (sub->ctx)
             mark_context(interp, sub->ctx);
         if (sub->outer_ctx)

Modified: branches/gc_api/src/pmc/task.pmc
==============================================================================
--- branches/gc_api/src/pmc/task.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/task.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -395,9 +395,9 @@
             Parrot_Task_attributes * const core_struct = PARROT_TASK(SELF);
 
             if (core_struct->codeblock)
-                pobject_lives(interp, (PObj*)core_struct->codeblock);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)core_struct->codeblock);
             if (core_struct->data)
-                pobject_lives(interp, (PObj*)core_struct->data);
+                Parrot_gc_mark_PObj_alive(interp, (PObj*)core_struct->data);
         }
     }
 

Modified: branches/gc_api/src/pmc/unmanagedstruct.pmc
==============================================================================
--- branches/gc_api/src/pmc/unmanagedstruct.pmc	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/pmc/unmanagedstruct.pmc	Sat May  9 00:17:36 2009	(r38621)
@@ -759,7 +759,7 @@
 
     VTABLE void mark() {
         if (PARROT_UNMANAGEDSTRUCT(SELF)->init)
-            pobject_lives(INTERP, (PObj *)PARROT_UNMANAGEDSTRUCT(SELF)->init);
+            Parrot_gc_mark_PObj_alive(INTERP, (PObj *)PARROT_UNMANAGEDSTRUCT(SELF)->init);
     }
 
 /*

Modified: branches/gc_api/src/stacks.c
==============================================================================
--- branches/gc_api/src/stacks.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/stacks.c	Sat May  9 00:17:36 2009	(r38621)
@@ -131,7 +131,7 @@
     for (; ; chunk = chunk->prev) {
         Stack_Entry_t  *entry;
 
-        pobject_lives(interp, (PObj *)chunk);
+        Parrot_gc_mark_PObj_alive(interp, (PObj *)chunk);
 
         if (chunk == chunk->prev)
             break;
@@ -139,7 +139,7 @@
         entry = STACK_DATAP(chunk);
 
         if (entry->entry_type == STACK_ENTRY_PMC && UVal_pmc(entry->entry))
-            pobject_lives(interp, (PObj *)UVal_pmc(entry->entry));
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)UVal_pmc(entry->entry));
     }
 }
 

Modified: branches/gc_api/src/sub.c
==============================================================================
--- branches/gc_api/src/sub.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/sub.c	Sat May  9 00:17:36 2009	(r38621)
@@ -80,15 +80,15 @@
 
     obj = (PObj *)ctx->current_sub;
     if (obj)
-        pobject_lives(interp, obj);
+        Parrot_gc_mark_PObj_alive(interp, obj);
 
     obj = (PObj *)ctx->current_object;
     if (obj)
-        pobject_lives(interp, obj);
+        Parrot_gc_mark_PObj_alive(interp, obj);
 
     obj = (PObj *)ctx->current_cont;
     if (obj && !PObj_live_TEST(obj))
-        pobject_lives(interp, obj);
+        Parrot_gc_mark_PObj_alive(interp, obj);
 
     if (ctx->caller_ctx)
         mark_context(interp, ctx->caller_ctx);
@@ -98,15 +98,15 @@
 
     obj = (PObj *)ctx->current_namespace;
     if (obj)
-        pobject_lives(interp, obj);
+        Parrot_gc_mark_PObj_alive(interp, obj);
 
     obj = (PObj *)ctx->lex_pad;
     if (obj)
-        pobject_lives(interp, obj);
+        Parrot_gc_mark_PObj_alive(interp, obj);
 
     obj = (PObj *)ctx->handlers;
     if (obj)
-        pobject_lives(interp, obj);
+        Parrot_gc_mark_PObj_alive(interp, obj);
 
 
     if (!ctx->n_regs_used)
@@ -115,7 +115,7 @@
     for (i = 0; i < ctx->n_regs_used[REGNO_PMC]; ++i) {
         obj = (PObj *)CTX_REG_PMC(ctx, i);
         if (obj)
-            pobject_lives(interp, obj);
+            Parrot_gc_mark_PObj_alive(interp, obj);
     }
 
     for (i = 0; i < ctx->n_regs_used[REGNO_STR]; ++i) {
@@ -125,7 +125,7 @@
              * yet tracked down */
             PObj_flag_CLEAR(is_PMC, obj);
             PObj_is_string_SET(obj);
-            pobject_lives(interp, obj);
+            Parrot_gc_mark_PObj_alive(interp, obj);
         }
     }
 }

Modified: branches/gc_api/src/vtables.c
==============================================================================
--- branches/gc_api/src/vtables.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/vtables.c	Sat May  9 00:17:36 2009	(r38621)
@@ -209,15 +209,15 @@
             continue;
 
         if (vtable->mro)
-            pobject_lives(interp, (PObj *)vtable->mro);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)vtable->mro);
         if (vtable->_namespace)
-            pobject_lives(interp, (PObj *)vtable->_namespace);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)vtable->_namespace);
         if (vtable->whoami)
-            pobject_lives(interp, (PObj *)vtable->whoami);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)vtable->whoami);
         if (vtable->provides_str)
-            pobject_lives(interp, (PObj *)vtable->provides_str);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)vtable->provides_str);
         if (vtable->pmc_class)
-            pobject_lives(interp, (PObj *)vtable->pmc_class);
+            Parrot_gc_mark_PObj_alive(interp, (PObj *)vtable->pmc_class);
     }
 }
 


More information about the parrot-commits mailing list
--- branches/gc_api/src/gc/system.c	Sat May  9 00:10:18 2009	(r38620)
+++ branches/gc_api/src/gc/system.c	Sat May  9 00:17:36 2009	(r38621)
@@ -262,16 +262,16 @@
              * free headers... */
             if (pmc_min <= ptr && ptr < pmc_max &&
                     is_pmc_ptr(interp, (void *)ptr)) {
                 /* ...so ensure that pobject_lives checks PObj_on_free_list_FLAG
                  * before adding it to the next_for_GC list, to have
                  * vtable->mark() called. */
-                pobject_lives(interp, (PObj *)ptr);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)ptr);
             }
             else if (buffer_min <= ptr && ptr < buffer_max &&
                     is_buffer_ptr(interp, (void *)ptr)) {
                 /* ...and since pobject_lives doesn't care about bufstart, it
                  * doesn't really matter if it sets a flag */
-                pobject_lives(interp, (PObj *)ptr);
+                Parrot_gc_mark_PObj_alive(interp, (PObj *)ptr);
             }
         }
     }
@@ -262,16 +262,16 @@
             if (pmc_min <= ptr && ptr < pmc_max &&
                     is_pmc_ptr(interp, (void *)ptr)) {
-                /* ...so ensure that pobject_lives checks PObj_on_free_list_FLAG
+                /* ...so ensure that Parrot_gc_mark_PObj_alive checks PObj_on_free_list_FLAG
                  * before adding it to the next_for_GC list, to have
                  * vtable->mark() called. */
@@ -262,16 +262,16 @@
             else if (buffer_min <= ptr && ptr < buffer_max &&
                     is_buffer_ptr(interp, (void *)ptr)) {
-                /* ...and since pobject_lives doesn't care about bufstart, it
+                /* ...and since Parrot_gc_mark_PObj_alive doesn't care about bufstart, it
                  * doesn't really matter if it sets a flag */

Modified: branches/gc_api/src/hash.c
==============================================================================